**********************************************************************************************************
* This file contains Stata code for all tables and figures in manuscript titled:
* "Financial Education versus Costly Counseling: How to Dissuade Borrowers from Choosing Risky Mortgages?"
* which is fortcoming in the American Economic Journal: Policy

* The study is based on CoreLogic LoanPerformance (LP) mortgage servicing data licensed to the Federal Reserve System as well
* as the non-public version of version of mortgage applications data collected under the Home Mortgage Disclosure Act (HMDA) that 
* include precise dates of mortgage applications and originations, as well as the identity of the lender.

* Although these datasets are not publicly available, CoreLogic runs an active data grant program for researchers.
* More details on this program are available at: https://www.corelogic.com/solutions/university-data-portal.aspx
* Using this code, it will be straightforward to replicate our main results with LP data.

* The public version of HMDA data only allows identification of mortgage application and origination dates up to a calendar year.


******************************************
cd O:/PROJ_LIB/hb4050/contractchoice

set more off

*****************************
* As first step, this program generates summary statistics tables
*****************************

* set data extension for use in subsequent analysis
* the extension signifies the approach used for building the synthetic control sample
* for instance, 'notype_fico' refers to drawing control loans from the sample of HMDA-LP matched loans, using FICO bins as one of the matching factors

local extension notype_fico
use data/matchvars_`extension', clear 

* groupbank is a replacement variable for HMDA bankid
egen groupbank=group(b_id)
drop b_id

*Flag active lenders, suing definition in section II.E 
 
gen before=(month>=ym(2006,1) & month<=ym(2006,8))
gen during=(month>=ym(2006,9) & month<=ym(2006,11))

* m1-m5 are the pilot months
g m1=month==ym(2006,9)
g m2=month==ym(2006,10)
g m3=month==ym(2006,11)
g m4=month==ym(2006,12)
g m5=month==ym(2007,1)

* Note: hb4050 is a flag set to 1 for hb4050 zip codes
keep if hb4050
collapse (sum) before during m1-m5, by(groupbank)

* average number of loans during the first 3 months of HB4050 is less than 10% of the average monthly volume during the preceding 8 months of 2006
g exit=((before/8)*.1 > (during/3))
* need to observe positive activity in each of the months of HB4050
g active=(exit==0 & m1>0 & m2>0 & m3>0 & m4>0 & m5>0) 
tab active
tempfile temp
save `temp',replace

use data/matchvars_`extension', clear 

sort groupbank 
merge m:1 groupbank using `temp', keep(master match) nogen

* the working dataset now has an identifier variables for banks that had remained active during the HB4050 period
*****************************

*bysort hb4050 time: sum default18 lowfico midfico highfico fico_orig doc_low_new risk_products1 risk_products2 margin ltv_ratio logvalue

*****************************
* Note: Table 1A is constructed using publicly availble 2000 Census data and 2005 IRS SOI zip-level data

* Table 1B: Summary statistics: pre-HB4050 data available to IDFPR in making zip code designations

* now N is defined to encompass all observations as none of the 'control' values is missing
g N=(control!=.)

*Time period
g time2005=1       if mofd(close_dt)>=ym(2005,1) & mofd(close_dt)<=ym(2005,12)

*Define the samples: HB4050, 12-zip control, and all Chicago other than HB4050
g b1=(hb4050==1    & time2005==1)
g b2=(control==1   & time2005==1)
g b3=(hb4050~=1    & time2005==1)

* first column for each group captures the mean, the second captures standard deviation
* then t-tests of means equality can be computed in Excel
preserve
matrix M=J(9,6,.)

forvalues b=1/3 {

local i=1 

foreach X in N default18 default36 fico_orig dti_dynamic_first doc_low_new ltv_ratio logvalue income {

   qui sum `X' if b`b'==1

    if `i'==1 {
      matrix M[`i',`b'*2-1]=r(N)
    }    
    else { 
      matrix M[`i',`b'*2-1]=r(mean)
	  matrix M[`i',`b'*2]=r(sd)
    }    

  local i=`i'+1
 
} 
*END X
} 
*END c

 clear
 svmat M
 export excel output/Table1B_`extension'.xlsx, sheet(`sample') sheetreplace firstrow(var)
 restore
 
 * run a joint test of predicting selection into the treated sample on the basis of observables
 * this should be done only on the pre-HB4050 time period
 
 * geographic control sample
 qui logit hb4050 default18 fico_orig dti_dynamic_first ltv_ratio logvalue if (b1 | b2)
  estadd scalar hb4050_c_df=e(df_m)
  estadd scalar hb4050_c_chi2=e(chi2)
  estadd scalar hb4050_c_p=e(p)
  eststo
	  
 * all non-HB4050 control sample
 qui logit hb4050 default18 fico_orig dti_dynamic_first ltv_ratio logvalue if (b1 | b3)
  estadd scalar hb4050_s_df=e(df_m)
  estadd scalar hb4050_s_chi2=e(chi2)
  estadd scalar hb4050_s_p=e(p)
  eststo
  
  esttab * using output/Table1B_joint_`extension'.csv, replace scalar(hb4050_c_df hb4050_c_chi2 hb4050_c_p hb4050_s_df hb4050_s_chi2 hb4050_s_p) 
 est clear

drop b1-b3 time2005


*****************************
* Table 1C: Summary statistics
* NOTE: this produces sample-level statistics. Zip-level equivalent of Table 1C data is available as an online data appendix

* Time periods
g time=1       if mofd(close_dt)>=ym(2005,1) & mofd(close_dt)<=ym(2006,8)
replace time=2 if mofd(close_dt)>=ym(2006,9) & mofd(close_dt)<=ym(2007,1)
replace time=3 if mofd(close_dt)> ym(2007,1)

* Define the samples
g c1=(hb4050==1    & time==1)
g c2=(control==1   & time==1)
g c3=(synthetic==1 & time==1)
g c4=(hb4050==1    & time==2)
g c5=(control==1   & time==2)
g c6=(synthetic==1 & time==2)
g c7=(hb4050==1    & time==3)
g c8=(control==1   & time==3)
g c9=(synthetic==1 & time==3)

g missing=.

preserve

* first column for each group captures the mean, the second captures standard deviation
* then t-tests of means equality can be computed in Excel

matrix M=J(17,18,.)

forvalues c=1/9 {

local i=1 

foreach X in N default18 default36 lowfico midfico highfico fico_orig risk_products1 risk_products2 doc_low_new margin_rate margin_alt dti_dynamic_first ltv_ratio logvalue dti_dynamic_avg	pmt_ratio_avg {

   qui sum `X' if c`c'==1

    if `i'==1 {
      matrix M[`i',`c'*2-1]=r(N)
    }    
    else { 
      matrix M[`i',`c'*2-1]=r(mean)
	  matrix M[`i',`c'*2]=r(sd)
    }    

  local i=`i'+1
 
} 
*END X
} 

*END c

 clear
 svmat M
 export excel output/Table1C_`extension'.xlsx, sheet(`sample') sheetreplace firstrow(var)
 restore
 
 drop c1-c6

*********************************
*Table 2: Mortgage Product Choice

local Yvars risk_products1 risk_products2

* NOTE: risk_products1 corresponds to I(Risky Products: Only Mid-FICO Counseled), as defined in text
* risk_products2 corresponds to I(Risky Products: Only Mid- and High-FICO Counseled)

* Treatment:

 gen hb4050_dummy=(month>=ym(2006,9) & month<=ym(2007,1) & hb4050==1)
 la var hb4050_dummy "HB4050 zip code AND pilot time"
 
 g piggyback = 0
 replace piggyback = 1 if (second_lien==1) & (ltv_ratio==100)
 
 g drop_helocs = 0
 replace drop_helocs = 1 if first_lien==1 | piggyback==1
 
* HB4050 did not have a very clear treatment of second-liens. Program guidance suggested that piggybacks were to be treated like first-lien loans
* but subsequent HELOCs were not. We use the CLTV indicator of 100 for second-lien loans to identify piggybacks. 
* Hence the drop_helocs sample includes first liens loans and those second liens that we identify as piggybacks
 
foreach Y of local Yvars {
  replace `Y'=`Y'*100
}

foreach x in low mid high {   
  g `x'hb4050=`x'fico*hb4050_dummy  
} 

label var lowhb4050  "HB 4050 x Low FICO"
label var midhb4050  "HB 4050 x Mid FICO"
label var highhb4050 "HB 4050 x High FICO"
label var risk_products1 "Risky Products: Category I"
label var risk_products2 "Risky Products: Category II"

***Regressions

local controls fico_orig logvalue ltv_ratio refi i.prop_type

* NOTE: logIRSincome is constructed with zip-level IRS SOI data. SOI data aggregate reported AGI and count of returns, used to construct per capita measures

format %tm month
est clear
fvset base 1 month zcta 

foreach Y of local Yvars { 
foreach active in N active {
foreach sample in hb4050control hb4050synthetic {
foreach restr in N drop_helocs { 

  qui reg `Y' lowhb4050 midhb4050 highhb4050  `controls'   i.month i.zcta i.month#c.logIRSincome if `active'==1 & `sample'==1 & `restr'==1, cluster(zcta)  
  
  * report the mean value of the outcome variable for the control group
  sum `Y' if e(sample)==1 & (hb4050==0)
  estadd scalar mean=r(mean)
  
  foreach x in low mid high {   
   qui sum `Y' if e(sample)==1 & (hb4050==0) & (time==2 & `x'fico==1)
   estadd scalar mean_`x'=r(mean)
   } 
  
  qui sum hb4050 if e(sample)==1
  estadd scalar hb4050=r(mean)  
  eststo
	
}
}
}
}

esttab * using output/table2_`extension'.csv, replace label b(%8.2f) star(* 0.1 ** 0.05 *** 0.01) se ar2 scalar(mean mean_low mean_mid mean_high hb4050) sfmt(%9.1f %9.3f) 
est clear

*********************************
*Table 3: Mortgage Product Choice Robustness Checks

*define subsamples for these tables

* baseline: 12 ZIP Active lenders, HELOCS kept
* subsamples are baseline + {refi only, drop August 2006, drop Madigan zip codes}

g refi_only = 0
replace refi_only = 1 if refi==1

g no_aug2006 = 0
replace no_aug2006 =1 if (mon~=ym(2006,8))

* Data from: http://statisticalatlas.com/state-lower-legislative-district/Illinois/District-22/Overview
* note that IL house districts do no align perfectly with ZIP codes. Hence, Madigan's district includes parts of these 4 ZIP codes

g no_Madigan = 0
replace no_Madigan = 1 if (zcta ~= 60629 & zcta ~= 60632 & zcta ~= 60638 & zcta ~= 60652)

* generate zip-specific time trends (linear)
* create a series of indicators for each zip code: {z1,...,z53} 
tabulate zcta, gen(z)

forvalues z=1(1)53 {
  gen time_`z' = 0
    replace time_`z'= (month-539)*z`z' if z`z'==1
}

local controls fico_orig logvalue ltv_ratio refi i.prop_type
local Yvars risk_products1 risk_products2
 
foreach Y of local Yvars { 
foreach restr in N refi_only no_aug2006 no_Madigan { 

  qui reg `Y' lowhb4050 midhb4050 highhb4050  `controls'   i.month i.zcta i.month#c.logIRSincome if (active==1 & hb4050control==1) & `restr'==1, cluster(zcta)

  * report the mean value of the outcome variable for the control group
  qui sum `Y' if e(sample)==1 & (hb4050==0)
  estadd scalar mean=r(mean)

  * report the mean for each of the FICO groups during the pilot period
  foreach x in low mid high {   
   qui sum `Y' if e(sample)==1 & (hb4050==0) & (time==2 & `x'fico==1)
   estadd scalar mean_`x'=r(mean)
   } 

  qui sum hb4050 if e(sample)==1
  estadd scalar hb4050=r(mean)  
  eststo
  
  * generate wild bootstrap values reported in Appendix Table 1
  /*boottest {midhb4050=0} {lowhb4050=0} {highhb4050=0}, boottype(wild) nograph
  estadd scalar low_t = r(t_2)
  estadd scalar low_p = r(p_2)
  estadd scalar mid_t = r(t_1)
  estadd scalar mid_p = r(p_1)
  estadd scalar high_t = r(t_3)
  estadd scalar high_p = r(p_3)*/

}
}

foreach Y of local Yvars { 

  qui reg `Y' lowhb4050 midhb4050 highhb4050  `controls'   i.month i.zcta time_* if (active==1 & hb4050control==1), cluster(zcta)  
  
  * report the mean value of the outcome variable for the control group
  qui sum `Y' if e(sample)==1 & (hb4050==0)
  estadd scalar mean=r(mean)

  * report the mean for each of the FICO groups during the pilot period
  foreach x in low mid high {   
   qui sum `Y' if e(sample)==1 & (hb4050==0) & (time==2 & `x'fico==1)
   estadd scalar mean_`x'=r(mean)
   } 

  qui sum hb4050 if e(sample)==1
  estadd scalar hb4050=r(mean)  
  eststo
  
  
}

* table31_ contains results for the active sample only
esttab * using output/table31_`extension'.csv, replace label b(%8.2f) star(* 0.1 ** 0.05 *** 0.01) se ar2 scalar(mean mean_low mean_mid mean_high hb4050) sfmt(%9.1f %9.3f) 

est clear

*********************************
* Table 4: Availability of certain contract types over time among active LP banks

* variables of interest
* NOTE: pp_pen, negam, io_all are LP fields that denote the presence of prepayment penalties, negative amortization, and interest only payments, respectively
* NOTE: is_hybrid is an indicator of a short-reset amortizing ARM loan, commonly known as Hybrid ARMs during the 2003-2007 period 
		* is_hybrid = 1 if (arm_all ==1 & first_rate <= 36) & (arm_rate_reset == 1 & first_rate > 0), where first_rate denotes the number of months before first interest rate reset


gen pp_pen_ind = (pp_pen=="Y")
gen negam_ind = negam=="Y"
gen io_hybrid_ind = (io_all == 1) | (is_hybrid == 1 & first_rate <= 36)

*Time periods: before HB4050, during HB4050, and after HB4050, respectively
g t4_time=1       if mofd(close_dt)>=ym(2005,9) & mofd(close_dt)<=ym(2006,8)
replace t4_time=2 if mofd(close_dt)>=ym(2006,9) & mofd(close_dt)<=ym(2007,1)
replace t4_time=3 if mofd(close_dt)>=ym(2007,2) & mofd(close_dt)<=ym(2007,6)

foreach X in doc_low_new io_hybrid_ind negam_ind pp_pen_ind {
 
 table groupbank hb4050 t4_time if (active==1 & hb4050control==1), c(sum `X')
 
 }

* these output tables containing raw counts of banks originating mortgage contracts of a given type
* are summarized in Excel where the tabulations present the fraction of all banks offering a certain contract type

 
 *********************************
*Table 5: Availability of low-Doc loans

local extension notype_fico
local controls fico_orig logvalue ltv_ratio refi i.prop_type
local Yvars risk_products1 risk_products2

replace doc_low_new=doc_low_new*100
 
foreach active in N active {
foreach sample in hb4050control hb4050synthetic {

  qui reg doc_low_new lowhb4050 midhb4050 highhb4050  `controls'   i.month i.zcta i.month#c.logIRSincome if (`active'==1 & `sample'==1), cluster(zcta)  
  
  qui sum doc_low_new if e(sample)==1 & (hb4050==0)
  estadd scalar mean=r(mean)
  
  foreach x in low mid high {   
   qui sum doc_low_new if e(sample)==1 & (hb4050==0) & (time==2 & `x'fico==1)
   estadd scalar mean_`x'=r(mean)
   } 
  
  qui sum hb4050 if e(sample)==1
  estadd scalar hb4050=r(mean)  
  eststo
 
}
}

esttab * using output/table5_`extension'.csv, replace label b(%8.2f) star(* 0.1 ** 0.05 *** 0.01) se ar2 scalar(mean mean_low mean_mid mean_high hb4050) sfmt(%9.1f %9.3f) 
est clear

*********************************
*Table 6: Mortgage Terms and Availability

* Note: margin_rate for FRMs is simply set to 0.
* as an alternative, margin_alt uses the difference between the contract rate and the FHMLC survey benchmark rate for FRMs
* g margin_alt = (arm_all * margin_rate) + (frm_all * (first_cur_int_rate - fhlmc_30yr))

* In both cases, for ARMs margin rate is defined by the contract directly

local extension notype_fico
local Yvars margin_rate margin_alt

local controls fico_orig logvalue ltv_ratio refi i.prop_type

foreach Y of local Yvars {
 replace `Y' = `Y'*100
 su `Y'
}

* LTV ratio first: here, it may be important to drop HELOCs, whose CLTV is irrelevant for purchase and refinance decisions studied here
foreach active in N active {
foreach sample in hb4050control hb4050synthetic {
foreach restr in N drop_helocs { 

  qui reg ltv_ratio lowhb4050 midhb4050 highhb4050  fico_orig logvalue refi i.prop_type i.month i.zcta i.month#c.logIRSincome if (`active'==1 & `sample'==1) & `restr'==1, cluster(zcta)  
  
  qui sum ltv_ratio if e(sample)==1 & (hb4050==0)
  estadd scalar mean=r(mean)
  
  foreach x in low mid high {   
   qui sum ltv_ratio if e(sample)==1 & (hb4050==0) & (time==2 & `x'fico==1)
   estadd scalar mean_`x'=r(mean)
   } 
  
  qui sum hb4050 if e(sample)==1
  estadd scalar hb4050=r(mean)  
  eststo

}
}
}

* Note: arm_all sample restrcits the margin analysis to only ARM loans

foreach Y in margin_rate margin_alt {
 foreach active in N active {
  foreach sample in hb4050control hb4050synthetic {
   foreach restr in N drop_helocs arm_all{ 

   qui reg `Y' lowhb4050 midhb4050 highhb4050  `controls'   i.month i.zcta i.month#c.logIRSincome if (`active'==1 & `sample'==1) & `restr'==1, cluster(zcta)  
  
   qui sum `Y' if e(sample)==1 & (hb4050==0)
   estadd scalar mean=r(mean)
   
   foreach x in low mid high {   
    qui sum `Y' if e(sample)==1 & (hb4050==0) & (time==2 & `x'fico==1)
    estadd scalar mean_`x'=r(mean)
   } 
   
   qui sum hb4050 if e(sample)==1
   estadd scalar hb4050=r(mean)  
   eststo
}
}
}
}

* Debt-service-to-income and affordability measures
* Keep in mind that only the back DTI ratio has reasonable coverage, but even that is missing for about 25% of observations
* The loan payment to loan amount ratio is computed on the basis of FIRST month required payment (see data_notype.do)

* Note: new measures of debt-to-income ratios use HMDA income data and mortgage payments from dynamic files
* these measures will be front-end by construction
* using first monthly payment only; note that tot_pmt_amt fields are largely empty, as they are reported directly by the servicer
* see data_notype.do for more details

* gen dti_dynamic_first = 0
* replace dti_dynamic_first =(first_sch_mnth_p_amt)/(income*1000/12) if income>0

* using average monthly payment instead
* gen dti_dynamic_avg = 0
* replace dti_dynamic_avg =(avg_sch_mnth_p_amt)/(income*1000/12) if income>0

* note: dti_ratio_back is already scaled
foreach Y in dti_dynamic_first dti_dynamic_avg pmt_ratio_first pmt_ratio_avg{
 replace `Y' = `Y' * 100
}

foreach Y in dti_ratio_back dti_dynamic_first dti_dynamic_avg pmt_ratio_first pmt_ratio_avg{

foreach active in N active {
foreach sample in hb4050control hb4050synthetic {

  qui reg `Y' lowhb4050 midhb4050 highhb4050  `controls'   i.month i.zcta i.month#c.logIRSincome if (`active'==1 & `sample'==1), cluster(zcta)  
  
  qui sum `Y' if e(sample)==1 & (hb4050==0)
  estadd scalar mean=r(mean)
  
  foreach x in low mid high {   
    qui sum `Y' if e(sample)==1 & (hb4050==0) & (time==2 & `x'fico==1)
    estadd scalar mean_`x'=r(mean)
   } 
   
  qui sum hb4050 if e(sample)==1
  estadd scalar hb4050=r(mean)  
  eststo



}
}
}

esttab * using output/table6_`extension'.csv, replace label b(%8.2f) star(* 0.1 ** 0.05 *** 0.01) se ar2 scalar(mean mean_low mean_mid mean_high hb4050) sfmt(%9.1f %9.3f) 
est clear


********************************************************
*Table AE1: Default rates 

* define three groups of interest:
* group_dummy = {1,2,3} for {HB4050, control, synthetic} during HB4050 period; missing otherwise
* note groups 2 and 3 are not mutually exclusive

* gen hb4050_dummy=(mon>=ym(2006,9) & mon<=ym(2007,1) & hb4050==1)
gen control_dummy=(mon>=ym(2006,9) & mon<=ym(2007,1) & control==1)
gen synthetic_dummy=(mon>=ym(2006,9) & mon<=ym(2007,1) & synthetic==1)

* identify all loans for the zip-based comparison sample  
gen hb4050_control_dummy = 0
replace hb4050_control_dummy = 1 if hb4050_dummy | control_dummy
la var hb4050_control_dummy "(HB4050 time and zip) + (HB4050 time & control zip)"

* identify all loans for the PSM-based comparison sample  
gen hb4050_synthetic_dummy = 0
replace hb4050_synthetic_dummy = 1 if hb4050_dummy | synthetic_dummy
la var hb4050_synthetic_dummy "(HB4050 time and zip) + (HB4050 time & synthetic)"


* capture the dates of default or exit from the sample; needed for hazard rates
gen first_def_date = min( first_delin_mba_9 , first_delin_mba_f , first_delin_mba_r , first_delin_mba_4 , first_delin_mba_5 )
format first_def_date %tm

gen first_exit_date = min( first_delin_mba_9 , first_delin_mba_f , first_delin_mba_r , first_delin_mba_4 , first_delin_mba_5, first_delin_mba_0 )
format first_exit_date %tm

* convert exit and default dates into loan-age time
gen age_at_first_def = first_def_date-mofd(close_dt)
gen age_at_first_exit = first_exit_date-mofd(close_dt)

* further subdivide the hb4050 group into those that were counseled and those that avoided counseling
* 0 remains the non-HB4050 group (control or synthetic), 1 is the hb4050-treated, and 2 is the hb4050 non-treated
gen hb4050_split = hb4050
replace hb4050_split = 2 if (hb4050) & ((midfico & risk_products1==0 & risk_products2==0) | (highfico & risk_products2==0))


* first iteration: create unconditional hazard rates for each of the three groups

foreach S in control synthetic {
foreach event in def exit {
foreach group in hb4050 hb4050_split {

preserve

* observations not used in comparisons can be dropped
drop if hb4050_`S'_dummy ~=1

* amount is simply a non-missing variable, any other such variable would do as well
collapse (count) orig_amt, by(age_at_first_`event' `group')


reshape wide orig_amt, i(age_at_first_`event') j(`group')

* outsheet using output/hazard_`event'_`S'_`group'.csv, comma replace
export excel output/hazard_data_`extension'.xlsx, sheet(`event'_`S'_`group') sheetreplace firstrow(var)

restore
}
}
}


********************************************************
*Table AE2: Adjusted Default rates

* this follows the approach of Demyanyk and van Hemert (2009)


local extension notype_fico_chk
drop default18 default36

forvalues a=1(1)50 {

* create a series of default indicators in each of the months
g default`a'=(	  (first_delin_mba_9-mofd(close_dt)<=`a' | first_delin_mba_f-mofd(close_dt)<=`a' | first_delin_mba_r-mofd(close_dt)<=`a' | first_delin_mba_4-mofd(close_dt)<=`a' | first_delin_mba_5-mofd(close_dt)<=`a') & (first_delin_mba_9!=. | first_delin_mba_f!=. | first_delin_mba_r!=. | first_delin_mba_4!=. | first_delin_mba_5!=.)) 

}

* estimate a logit model for 'a'-period default on the basis of loan and borrower characteristics; store predicted probability of default
* note 'capture' allows the loop to proceed even in cases where estimation for some 'a' is infeasible because there is not enough observations
* e.g., default1 is virtually never 1

local controls fico_orig logvalue ltv_ratio refi i.prop_type

forvalues a=1(1)50 {
 foreach sample in control synthetic {
  foreach active in N active {
 
* estimate default models on a full (i.e., pre-, during, and post-HB4050) sample of treated and control loans
* as an alternative, consider estimmating default models using only loans originated in the pre-HB4050 period (this is done by requiring time==1 and dropping /*if e(sample)*/ in predict)

* another alternative is to estimate default ONLY on non-HB4050 loans, but using both pre-, during- and post-periods: (hb4050`sample'==1 & hb4050==0)
* NOTE: we can further force the default model to be estimated on non-HB4050 loans originated by lenders that stayed active (in HB4050 zips?)

capture logit default`a' `controls' i.month i.zcta  if (hb4050`sample'==1 & `active'==1 & hb4050==0)  
capture predict predict_`a'_`sample'_`active' 

* construct confidence intervals for each predicted value

capture predict lr_index, xb
capture predict se_index, stdp

capture gen lb = lr_index - invnormal(0.975)*se_index
capture gen ub = lr_index + invnormal(0.975)*se_index
capture gen plb = exp(lb)/(1+exp(lb))
capture gen pub = exp(ub)/(1+exp(ub))

* compute average actual and predicted 'a'-month default rate for each hb4050_split group
* however, this is done only for loans originated DURING the HB4050 treatment period
* note: this value should be the same for each loan in a given hb4050_split group

capture egen default`a'_pred_`sample'_`active' = mean(predict_`a'_`sample'_`active') if hb4050_`sample'_dummy & `active'==1, by(hb4050_split)
capture egen default`a'_lb_`sample'_`active' = mean(plb) if hb4050_`sample'_dummy & `active'==1, by(hb4050_split)
capture egen default`a'_ub_`sample'_`active' = mean(pub) if hb4050_`sample'_dummy & `active'==1, by(hb4050_split)

capture egen default`a'_act_`sample'_`active' = mean(default`a') if hb4050_`sample'_dummy & `active'==1, by(hb4050_split)
* capture drop predict_`a'
capture drop lr_index se_index lb ub plb pub
  }
 }
}

* prepare output

foreach sample in control synthetic{
  foreach active in N active {

  capture preserve
  collapse (count) default18 (mean) default*_`sample'_`active' if hb4050_`sample'_dummy & `active'==1, by(hb4050_split)
  export excel output/adjusted_defaults_`extension'.xlsx, sheet(`sample'_`active') sheetreplace firstrow(var)
  restore

 }
}

********************************************************
* Table 7: Re-do rejection rate analysis without partitioning the sample by lender type

* use data\HMDA applications ZIP allocated.dta, clear
* use data\CHMDA applications 2005_07.dta, clear

import delimited O:\PROJ_LIB\hb4050\contractchoice\data\chmda058619_2001502208602.csv

rename county_code county
rename census_tract tract

sort county tract

merge m:1 county tract using "O:\PROJ_LIB\hb4050\contractchoice\data\IL tract to zip mapping unique.dta"
tabulate _merge

destring zcta5, gen(zcta)

*Chicago zip codes in the original dataset: 56 zip codes altogether; some are just P.O.Box zips like O'Hare and Merchandise Mart
g k=0
replace k=1 if inlist(zcta,60601,60602,60603,60604,60605,60606,60607,60608,60609)
replace k=1 if inlist(zcta,60610,60611,60612,60613,60614,60615,60616,60617,60618)
replace k=1 if inlist(zcta,60619,60620,60621,60622,60623,60624,60625,60626,60628) 
replace k=1 if inlist(zcta,60629,60630,60631,60632,60633,60634,60636,60637,60638) 
replace k=1 if inlist(zcta,60639,60640,60641,60643,60644,60645,60646,60647,60649)
replace k=1 if inlist(zcta,60651,60652,60653,60654,60655,60656,60657,60659,60660,60661,60827)

* satisfied by construction
* g j=(int(cl_date/100)>=2005 & int(cl_date/100)<=2007)

* keep only Chicago zip codes during the evaluation window
keep if k==1

**** Identify the active lender subset
egen groupbank=group(respondent_id)

*Flag active lenders 
* NOTE: without HMDA match, this step is irrelevant, as we cannot identify individual lenders
 
*New definition of active

gen month = int(action_date/100)

gen before=(month>=200601 & month<=200608)
gen during=(month>=200609 & month<=200611)

g m1=month==200609
g m2=month==200610
g m3=month==200611
g m4=month==200612
g m5=month==200701

*groupbank is a replacement variable for HMDA bankid; there are 520 unique groupbank values in the entire sample
* there are only 121 unique lenders if we base active on lending in HB4050

* NOTE: defining "active" on the set of lenders opertaing in HB4050 zip codes ONLY substantially reduces the loan sample
* However, it effectively forces both treatment and control groups to consist of the same group of lenders 

g hb4050=(inlist(zcta, 60620, 60621, 60623, 60628, 60629, 60632, 60636, 60638, 60643, 60652))
g control=(zcta==60639 | zcta==60641 | zcta==60644 | zcta==60624 | zcta==60609 | zcta==60637 | zcta==60649 | zcta==60619 | zcta==60617 | zcta==60655 | zcta==60633 | zcta==60827)
g hb4050control=(hb4050==1 | control==1)

gen hb4050_time = (hb4050==1 & (action_date>=20060901 & action_date<=20070101))
save data\"CHMDA applications 2005_07.dta", replace


keep if hb4050
collapse (sum) before during m1-m5, by(groupbank)

* average number of loans during the first 3 months of HB4050 is less than 10% of the average monthly volume during the preceding 8 months of 2006
g exit=((before/8)*.1 > (during/3))
* need to observe positive activity in each of the months of HB4050
g active=(exit==0 & m1>0 & m2>0 & m3>0 & m4>0 & m5>0) 
tab active
tempfile temp
save `temp',replace

use data\CHMDA_applications_2005_07.dta, clear 

sort groupbank 
merge m:1 groupbank using `temp', keep(master match) nogen
***********************************************
* Now we have the active subset identified as well

* merge with IRS data to obtain log(oncome)*zip FE controls
sort zcta year
merge m:1 zcta year using data/irs_merge1, keep(match) keepusing(returns agi IRS_agi) nogen
gen logIRSincome = ln(IRS_agi)


** From HMDA: action 2 -- Application approved but not accepted
gen borrower_reject = 0
replace borrower_reject = 1 if action_type==2

local controls fico_orig logvalue ltv_ratio refi i.prop_type

gen log_amount = ln(loan_amount)
gen log_income = ln(applicant_income)

reg borrower_reject hb4050_time hb4050 log_amount log_income i.loan_purpose i.occupancy i.month i.zcta if (hb4050control==1), cluster(zcta)

sum borrower_reject if e(sample)==1 & (hb4050==0) & (during==1)
    estadd scalar mean=r(mean)
    eststo 

* on the active subsample	
reg borrower_reject hb4050_time hb4050 log_amount log_income i.loan_purpose i.occupancy i.month i.zcta if (hb4050control==1 & active==1), cluster(zcta)

sum borrower_reject if e(sample)==1 & (hb4050==0) & (during==1)
    estadd scalar mean=r(mean)
    eststo 
	
esttab * using output/table7.csv, replace label b(%8.2f) star(* 0.1 ** 0.05 *** 0.01) se ar2 scalar(mean) sfmt(%9.2f %9.2f) 



********************************************************
*Table AR1_1: Bootstrapped standard errors

* baseline: geogrpaphic control sample with 12 ZIPs, HELOCS kept
* goal: test the robiustness of cluster-adjusted standard errors when the number of zip codes is small.
* use the wild bootstrap procedure in 
* apply this approach to our main results in Table 3 on product choice, report bootstrapped confidence intervals.

local controls fico_orig logvalue ltv_ratio refi i.prop_type
local Yvars risk_products1 risk_products2
local extension notype_fico

preserve 

* matrix Boot = J(3,8,.)
matrix A = J(3,1,0)
 
foreach Y of local Yvars { 
foreach restr in N active{ 

  * standard cluster adjustment
  qui reg `Y' lowhb4050 midhb4050 highhb4050  `controls'   i.month i.zcta i.month#c.logIRSincome if (hb4050control==1) & `restr'==1, cluster(zcta)  
  eststo
  
  * generate wild bootstrap values
  boottest {midhb4050=0} {lowhb4050=0} {highhb4050=0}, boottype(wild) nograph
  
  * store the resulting confidence intervals
  * initialize
  
  matrix L = J(1,2,.)
  matrix M = J(1,2,.)
  matrix H = J(1,2,.)

  matrix L = r(CI_2)
  matrix M = r(CI_1)
  matrix H = r(CI_3)

  matrix temp = [L \ M \ H]
  matrix A = [A , temp]
    
}
}


* first want to save the regression output with confidence intervals
 esttab * using output/tableAR1_CI_`extension'.csv, replace label b(%8.2f) star(* 0.1 ** 0.05 *** 0.01) ci ar2  
 est clear
 
 clear
 svmat A
 export excel output/tableAR1_Bootstrap_`extension'.xlsx, sheet(`sample') sheetreplace firstrow(var)
 restore 
 

*****************************
* DATA APPENDIX: Summary statistics as in Table 1C, but broken out by zip code


* At this point in the code, time = {1,2,3} is already defined
* g time=1       if mofd(close_dt)>=ym(2005,1) & mofd(close_dt)<=ym(2006,8)
* replace time=2 if mofd(close_dt)>=ym(2006,9) & mofd(close_dt)<=ym(2007,1)
* replace time=3 if mofd(close_dt)> ym(2007,1)

* Define the zip-level samples
*g hb4050=(inlist(zcta, 60620, 60621, 60623, 60628, 60629, 60632, 60636, 60638, 60643, 60652))
*g control=(zcta==60639 | zcta==60641 | zcta==60644 | zcta==60624 | zcta==60609 | zcta==60637 | zcta==60649 | zcta==60619 | zcta==60617 | zcta==60655 | zcta==60633 | zcta==60827)
*g hb4050control=(hb4050==1 | control==1)

local extension raw
preserve

* first column for each group captures the mean, the second captures standard deviation
* then t-tests of means equality can be computed in Excel

* This version of data summary produces tables formatted like Table 1C
local z=1 
* fix number of variables to report
local nv=15

* Matrix stores 15 vars * 22 zip codes = 330 rows, over 3 periods with means and sd in separate columns
matrix M=J(330,6,.)

* loop over zipcodes (10 treated + 12 controls)
foreach val in 60620 60621 60623 60628 60629 60632 60636 60638 60643 60652 60639 60641 60644 60624 60609 60637 60649 60619 60617 60655 60633 60827 {

* loop over time periods (before, during, and after)
forvalues tt=1/3 {

local i=1 

* loop over variables
foreach X in N default18 default36 lowfico midfico highfico fico_orig risk_products1 risk_products2 doc_low_new margin_alt ltv_ratio logvalue dti_dynamic_avg pmt_ratio_avg {

   qui sum `X' if zcta == `val' & time == `tt'
  
    * `i'==1 denotes a new zip_x_time group 
    if `i'==1 {
      matrix M[`i' + `nv' * (`z'-1) ,`tt'*2-1]=r(N)
	  matrix M[`i' + `nv' * (`z'-1),`tt'*2]=`val'
    }    
    else { 
      matrix M[`i' + `nv' * (`z'-1),`tt'*2-1]=r(mean)
	  matrix M[`i' + `nv' * (`z'-1),`tt'*2]=r(sd)
    }    

  local i=`i'+1
 
} 
*END X
} 
*END c

local z = `z'+1
}
*END zcta

***********************************************************************
* This version of data summary produces tables formatted as raw data, which is better suited for analysis

** Reset
local z=1 
* fix number of variables to report
local nv=14

* Matrix M2 stores 14 vars * 22 zip codes * 3 periods with N, mean, and sd in separate columns
matrix M2=J(924,6,.)

* loop over zipcodes (10 treated + 12 controls)
foreach val in 60620 60621 60623 60628 60629 60632 60636 60638 60643 60652 60639 60641 60644 60624 60609 60637 60649 60619 60617 60655 60633 60827 {
 
* loop over time periods (before, during, and after)
forvalues tt=1/3 {

local i=1 

* loop over variables
foreach X in default18 default36 lowfico midfico highfico fico_orig risk_products1 risk_products2 doc_low_new margin_alt ltv_ratio logvalue dti_dynamic_avg pmt_ratio_avg {

   qui sum `X' if zcta == `val' & time == `tt'
    
    local curr_row = `nv' * (`tt'-1) + `nv' * 3 * (`z'-1)
		
    matrix M2[`i' + `curr_row',2]=`val'
	matrix M2[`i' + `curr_row',3]=`tt'
    matrix M2[`i' + `curr_row',4]=r(N)
    matrix M2[`i' + `curr_row',5]=r(mean)
	matrix M2[`i' + `curr_row',6]=r(sd)
    
  * i is incremented with each new variable in X 	
  local i=`i'+1
 
} 
*END X
} 
*END c
 * z is incremented with each zip code
local z = `z'+1
}

 clear
 svmat M2
 export excel output/DataAppendix_Table1C_2`extension'.xlsx
 restore

