* This program uses a propensity score matching algorithm to construct a synthetic control sample for HB4050 loans
* It forces all potential matches to be within a pre-set FICO score bucket and month of origination

set more off
tempfile temp
save `temp',replace

local matchgroup monthlender

*** Implement the match ***

* sort observations in random order to avoid biasing the match
* however, this creates the problem of generating a new match each time the program is rerun (since matching is done w/o replacement)

* note that loan-to-loan matching is done after loan_id and b_id information has been scrambled
g _rand=runiform()
sort _rand
capture drop _*
g fico2=fico_orig^2
g ltv80=ltv_ratio>80 if ltv_ratio!=.
g dti0=dti_ratio_back==0 if dti_ratio_back!=. 

* generate discrete FICO buckets in data_notype.do
gen fico_group = 1*lowfico + 2*midfico + 3*highfico

* create 108 distinct groups: 36 months x 3 FICO groups
egen monthlender=group(month fico_group) if fico_group!=. 


*Note: specifying outcome() does not affect _pscore or _n1
		   
sum `matchgroup'
local max=r(max)
local min=r(min) 

local k=0


* for each of the distinct groups, find the nearest neighbor using psmatch2
* syntax below suggests matching done on the 1-1 basis by minimizing the geometric distance mamong covariates in {fico_orig fico2 logvalue   refi dti_ratio_back dti0 ltv_ratio ltv80}
* between observations in the treatment (hb4050=1) and control (hb4050=0) groups

* psmatch2 generates _id, which is a new identifier created for all observations
* ... and _n1, which in the case of one-to-one matching, for every treatment observation, stores the observation number of the 1-st matched control observation

forvalues t=`min'/`max' {

capture drop _*
local k=`k'+1

*Predict the propensity score

  capture psmatch2 hb4050 fico_orig fico2 logvalue   refi ltv_ratio ltv80   if `matchgroup'==`t',  noreplacement
 
  capture noisily g id`k'=_id
  capture noisily g nn`k'=_n1

}

* for each loan, keep its temporary id and the id of its nearest-matched non-treated loan
* E.g. a treatment loan in month k will be matched (if at all) with a control loan in month k. 
* that control loan's temporary id will be stored in nn`k'. All other nn's (1-36) will contain missing values

* the challenge is to translate those temporary control id's to permanent grouploan values for control loans

keep grouploan id* nn*
reshape long id nn, i(grouploan) j(k)

*Get the (unique) matched loans from the untreated group
preserve
keep nn k 
drop if nn==.
sort nn k
rename nn id
tempfile a
save `a',replace

* for each month, keep the temporary id of the matched control loan. Note that this file no longer contains the grouploan value of the treated loan matched to this control

restore 
sort id k 


*Match the loans from the untreated group to the appropriate loan_id
merge 1:1 id k using `a'

* Keep untreated matched loan_id and treated matched loan_id
* all observations for which _m==1 will come from the HB4050 (treatment) set and so they will have non-missing values for nn
* those nn values contain temporary id's of control group loans associated with the treated grouploan
* all observations with _m==3, in contrast, are from the control group. Their id variable contains the same temporary id as the one capture in the nn variable of their matched treated loan
* hence, ic can be used to link the permanent id (grouploan) of each pair of treatment and control loans

* this file contains all synthetic sample loans: treatment and control
keep if _m==3 | nn!=. 

preserve

keep grouploan 
g synthetic=1
sort grouploan
tempfile b
save `b',replace

restore

* this file contains a crosswalk between treatment and matched control grouploan ids

preserve
keep if _m==1
drop id
rename nn id
sort k id
tempfile c
save `c', replace

restore
keep if _m==3
drop nn
sort k id
rename grouploan matched_grouploan

merge 1:1 k id using `c', nogen
sort grouploan
tempfile d
save `d', replace

clear


***************************
*Restrict to matched sample 

use `temp'

sort grouploan 
merge 1:1 grouploan using `b', keep(master match) nogen
merge 1:1 grouploan using `d', keep(master match) nogen














